package com.vendor.burn.model.devices.unknown;

package .var.folders.cl.9twcgjfx4vsg5zl73c6wxmvm0000gn.T;

import com.vendor.burn.model.define.IBurner;
import com.vendor.burn.model.devices.IBurnerContext;
import com.vendor.burn.model.devices.IDeviceSetting;
import com.vendor.burn.model.devices.burners.AddressBurner;
import com.vendor.burn.model.devices.burners.CheckSumBurner;
import com.vendor.burn.model.devices.burners.CommonBurner;
import com.vendor.burn.model.devices.burners.DdrBurner;
import com.vendor.burn.model.devices.burners.DdrCheckBurner;
import com.vendor.burn.model.devices.burners.EmmcBurner;
import com.vendor.burn.model.devices.burners.FastbootBurner;
import com.vendor.burn.model.devices.burners.MergeBurner;
import com.vendor.burn.model.devices.burners.OneImageBurner;
import com.vendor.burn.model.devices.burners.PartitionBurner;
import com.vendor.burn.model.devices.burners.Uploader;
import com.vendor.burn.model.devices.unknown.UDProperties;
import com.vendor.burn.model.devices.unknown.UnknownDevice;
import com.vendor.burn.utilitily.StringUtils;
import java.util.ArrayList;

public class UDBurnerContext implements IBurnerContext {
  IDeviceSetting deviceSetting;
  
  IBurner[] burners;
  
  public static com.vendor.burn.model.devices.unknown.UDBurnerContext build(UDProperties properties, IDeviceSetting deviceSetting) {
    com.vendor.burn.model.devices.unknown.UDBurnerContext burnerContext = new com.vendor.burn.model.devices.unknown.UDBurnerContext();
    if (burnerContext.init(properties, deviceSetting))
      return burnerContext; 
    return null;
  }
  
  private boolean init(UDProperties properties, IDeviceSetting deviceSetting) {
    this.deviceSetting = deviceSetting;
    if (properties == null)
      return false; 
    ArrayList<IBurner> burnerList = new ArrayList<>();
    Integer commonPartition = properties.queryForInteger("CommonPartition");
    burnerList.add(new PartitionBurner(deviceSetting.getBurnContext()));
    String chipType = properties.queryForString("ChipType");
    int chipId = StringUtils.str2Num(chipType);
    if (chipId <= 768 && chipId >= 512) {
      burnerList.add(new OneImageBurner(deviceSetting.getBurnContext()));
      burnerList.add(new Uploader(deviceSetting.getBurnContext()));
      this.burners = new IBurner[burnerList.size()];
      burnerList.toArray(this.burners);
      return true;
    } 
    if (commonPartition != null && commonPartition.intValue() == 1) {
      burnerList.add(new CommonBurner(deviceSetting.getBurnContext()));
      burnerList.add(new AddressBurner(deviceSetting.getBurnContext()));
      burnerList.add(new FastbootBurner(deviceSetting.getBurnContext()));
      Integer emmcInt = properties.queryForInteger("EMMC");
      if (emmcInt != null && emmcInt.intValue() > 0)
        ((UnknownDevice)deviceSetting).setEmmcType(emmcInt.intValue()); 
    } else {
      initNotCommonPart(properties, deviceSetting, burnerList);
    } 
    initBurner(properties, deviceSetting, burnerList);
    this.burners = new IBurner[burnerList.size()];
    burnerList.toArray(this.burners);
    return true;
  }
  
  private void initNotCommonPart(UDProperties properties, IDeviceSetting deviceSetting, ArrayList<IBurner> burnerList) {
    String boardType = properties.queryForString("TYPE");
    if (boardType == null || !boardType.equalsIgnoreCase("CAM")) {
      burnerList.add(new PartitionBurner(deviceSetting.getBurnContext()));
      burnerList.add(new AddressBurner(deviceSetting.getBurnContext()));
      burnerList.add(new FastbootBurner(deviceSetting.getBurnContext()));
      Integer emmcInt = properties.queryForInteger("EMMC");
      if (emmcInt != null && emmcInt.intValue() > 0) {
        burnerList.add(new EmmcBurner(deviceSetting.getBurnContext()));
        ((UnknownDevice)deviceSetting).setEmmcType(emmcInt.intValue());
      } 
    } else {
      burnerList.add(new Object(this, deviceSetting.getBurnContext()));
      burnerList.add(new Object(this, deviceSetting.getBurnContext()));
      burnerList.add(new Object(this, deviceSetting.getBurnContext()));
      Integer emmcInt = properties.queryForInteger("EMMC");
      if (emmcInt != null && emmcInt.intValue() > 0) {
        burnerList.add(new Object(this, deviceSetting.getBurnContext()));
        ((UnknownDevice)deviceSetting).setEmmcType(emmcInt.intValue());
      } 
    } 
  }
  
  private void initBurner(UDProperties properties, IDeviceSetting deviceSetting, ArrayList<IBurner> burnerList) {
    Integer notSpiInt = properties.queryForInteger("NOTSPI");
    if (notSpiInt == null)
      burnerList.add(new MergeBurner(deviceSetting.getBurnContext())); 
    Integer checkSumInt = properties.queryForInteger("CHECKSUM");
    if (checkSumInt != null && checkSumInt.intValue() == 1)
      burnerList.add(new CheckSumBurner(deviceSetting.getBurnContext())); 
    Integer ddrBurn = properties.queryForInteger("DDRBURN");
    if (ddrBurn != null && ddrBurn.intValue() == 1)
      burnerList.add(new DdrBurner(deviceSetting.getBurnContext())); 
    burnerList.add(new DdrCheckBurner(deviceSetting.getBurnContext()));
  }
  
  public IBurner[] getBurners() {
    return (IBurner[])this.burners.clone();
  }
  
  public IDeviceSetting getDeviceSetting() {
    return this.deviceSetting;
  }
}
